@@ -14,7 +14,7 @@ from gi.repository import Gtk, Gdk, GObject, GdkPixbuf
 
 from math import pi
 
-from lollypop.define import Lp, ArtSize
+from lollypop.define import Lp, ArtSize, Type
 from lollypop.cache import InfoCache
 from lollypop.objects import Album
 
@@ -26,12 +26,22 @@ class CellRendererAlbum(Gtk.CellRenderer):
         Gtk.CellRenderer.__init__(self)
 
     def do_render(self, ctx, widget, background_area, cell_area, flags):
+        if self.album == Type.NONE:
+            return
         surface = Lp().art.get_album_artwork(Album(self.album),
                                              ArtSize.MEDIUM,
                                              widget.get_scale_factor())
         width = surface.get_width()
         height = surface.get_height()
-        ctx.translate(cell_area.x, cell_area.y)
+        # If cover smaller than wanted size, translate
+        translate_x = cell_area.x
+        translate_y = cell_area.y
+        wanted = ArtSize.MEDIUM * widget.get_scale_factor()
+        if width < wanted:
+            translate_x += (wanted - width) / 2
+        if height < wanted:
+            translate_y += (wanted - height) / 2
+        ctx.translate(translate_x, translate_y)
         ctx.new_sub_path()
         radius = 2
         degrees = pi / 180
@@ -49,7 +59,10 @@ class CellRendererAlbum(Gtk.CellRenderer):
         ctx.paint()
 
     def do_get_preferred_width(self, widget):
-        size = ArtSize.MEDIUM + 2
+        if self.album == Type.NONE:
+            size = 0
+        else:
+            size = ArtSize.MEDIUM + 2
         return (size, size)
 
     def do_get_preferred_height(self, widget):
@@ -96,7 +109,7 @@ class CellRendererArtist(Gtk.CellRendererText):
         if self.rowid in self._surfaces.keys():
             surface = self._surfaces[self.rowid]
         if surface is None:
-            for suffix in ["lastfm", "spotify", "wikipedia"]:
+            for suffix in ["lastfm", "deezer", "spotify", "wikipedia"]:
                 uri = InfoCache.get_artwork(self.artist, suffix, size)
                 if uri is not None:
                     pixbuf = GdkPixbuf.Pixbuf.new_from_file_at_size(uri,
