@@ -110,11 +110,12 @@ class TracksDatabase:
 
     def get_ids(self):
         """
-            Return all tracks id
-            @return tracks id as [int]
+            Return all internal track ids
+            @return track ids as [int]
         """
         with SqlCursor(Lp().db) as sql:
-            result = sql.execute("SELECT rowid FROM tracks")
+            result = sql.execute("SELECT rowid FROM tracks\
+                                  WHERE mtime>1")
             return list(itertools.chain(*result))
 
     def get_ids_for_name(self, name):
@@ -214,6 +215,7 @@ class TracksDatabase:
                          WHERE rowid=?",
                         (uri, track_id))
             sql.commit()
+            Lp().tracks.set_mtime(track_id, 0)
 
     def get_album_id(self, track_id):
         """
@@ -330,20 +332,6 @@ class TracksDatabase:
                 return v[0]
             return 0
 
-    def get_position(self, track_id):
-        """
-            Get track duration for track id
-            @param Track id as int
-            @return duration as int
-        """
-        with SqlCursor(Lp().db) as sql:
-            result = sql.execute("SELECT tracknumber FROM tracks\
-                                  WHERE rowid=?", (track_id,))
-            v = result.fetchone()
-            if v is not None and v[0] is not None:
-                return v[0]
-            return 0
-
     def get_duration(self, track_id):
         """
             Get track duration for track id
@@ -657,9 +645,13 @@ class TracksDatabase:
             return: list of [id as int, name as string]
         """
         with SqlCursor(Lp().db) as sql:
-            result = sql.execute("SELECT rowid, name FROM tracks\
-                                  WHERE noaccents(name) LIKE ? LIMIT 25",
-                                 ('%' + noaccents(searched) + '%',))
+            result = sql.execute("SELECT tracks.rowid, tracks.name\
+                                  FROM tracks, track_genres\
+                                  WHERE noaccents(name) LIKE ?\
+                                  AND tracks.rowid=track_genres.track_id\
+                                  AND track_genres.genre_id!=? LIMIT 25",
+                                 ('%' + noaccents(searched) + '%',
+                                  Type.CHARTS))
             return list(result)
 
     def search_track(self, artist, title):
