@@ -41,7 +41,8 @@ class MPRIS(dbus.service.Object):
 
     @dbus.service.method(dbus_interface=MPRIS_IFACE)
     def Raise(self):
-        self._app.activate()
+        self.__app.window.setup_window()
+        self.__app.window.present()
 
     @dbus.service.method(dbus_interface=MPRIS_IFACE)
     def Quit(self):
@@ -179,7 +180,8 @@ class MPRIS(dbus.service.Object):
                 ", ".join(Lp().player.current_track.album_artists)
             self._metadata['mpris:length'] = dbus.Int64(
                 Lp().player.current_track.duration * 1000000)
-            self._metadata['xesam:genre'] = [Lp().player.current_track.genres]
+            self._metadata['xesam:genre'] = Lp().player.current_track.genres\
+                or "Youtube"
             self._metadata['xesam:url'] = Lp().player.current_track.uri
             self._metadata["xesam:userRating"] = \
                 Lp().player.current_track.get_popularity() / 5
