@@ -10,6 +10,11 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
+from gi.repository import Gio
+
+from pickle import load
+from gettext import gettext as _
+
 from lollypop.player_bin import BinPlayer
 from lollypop.player_queue import QueuePlayer
 from lollypop.player_linear import LinearPlayer
@@ -21,8 +26,6 @@ from lollypop.radios import Radios
 from lollypop.objects import Track
 from lollypop.define import Lp, Type, NextContext, DataPath
 
-from pickle import load
-
 
 class Player(BinPlayer, QueuePlayer, UserPlaylistPlayer, RadioPlayer,
              LinearPlayer, ShufflePlayer, ExternalsPlayer):
@@ -42,6 +45,7 @@ class Player(BinPlayer, QueuePlayer, UserPlaylistPlayer, RadioPlayer,
         RadioPlayer.__init__(self)
         ExternalsPlayer.__init__(self)
         self.update_crossfading()
+        self.__do_not_update_next = False
 
     @property
     def current_track(self):
@@ -110,6 +114,19 @@ class Player(BinPlayer, QueuePlayer, UserPlaylistPlayer, RadioPlayer,
             RadioPlayer.load(self, track)
         else:
             if play:
+                if track.is_youtube and\
+                        not Gio.NetworkMonitor.get_default(
+                                                     ).get_network_available():
+                    if Lp().notify is not None:
+                        Lp().notify.send(_("No network available,"
+                                           " can't play this track"),
+                                         track.uri)
+                    # Force widgets to update (spinners)
+                    self.emit('current-changed')
+                    return
+                # Do not update next if user clicked on a track
+                if self.is_party and track != self._next_track:
+                    self.__do_not_update_next = True
                 BinPlayer.load(self, track)
             else:
                 BinPlayer._load_track(self, track)
@@ -121,15 +138,6 @@ class Player(BinPlayer, QueuePlayer, UserPlaylistPlayer, RadioPlayer,
             @param album as Album
         """
         self.shuffle_albums(False)
-        # Add album to main playlist if nothing playing
-        # Do not start to play
-        if not self._albums and self._current_track.id is None:
-                self.load(album.tracks[0], False)
-                self._albums = [self._current_track.album.id]
-                self._context.genre_ids[self._current_track.album.id] = []
-                self._context.artist_ids[self._current_track.album.id] = []
-                self._user_playlist = []
-                self._user_playlist_ids = []
         # If album already exists, merge genres/artists
         if album.id in self._albums:
             genre_ids = self._context.genre_ids[album.id]
@@ -382,7 +390,7 @@ class Player(BinPlayer, QueuePlayer, UserPlaylistPlayer, RadioPlayer,
                     url = radios.get_url(name)
                     track.set_radio(name, url)
                     self.load(track)
-                elif Lp().tracks.get_path(track_id) != "":
+                elif Lp().tracks.get_uri(track_id) != "":
                     track = Track(track_id)
                     if Lp().notify is not None:
                         Lp().notify.inhibit()
@@ -479,37 +487,41 @@ class Player(BinPlayer, QueuePlayer, UserPlaylistPlayer, RadioPlayer,
         except Exception as e:
             print("Player::set_prev", e)
 
-    def set_next(self):
+    def set_next(self, force=False):
         """
             Play next track
             @param sql as sqlite cursor
+            @param force as bool
         """
         try:
             # Reset finished context
             self._finished = NextContext.NONE
 
             # Look at externals
-            self._next_track = ExternalsPlayer.next(self)
+            next_track = ExternalsPlayer.next(self)
 
             # Look at radio
-            if self._next_track.id is None:
-                self._next_track = RadioPlayer.next(self)
+            if next_track.id is None:
+                next_track = RadioPlayer.next(self)
 
             # Look first at user queue
-            if self._next_track.id is None:
-                self._next_track = QueuePlayer.next(self)
+            if next_track.id is None:
+                next_track = QueuePlayer.next(self)
 
             # Look at user playlist then
-            if self._next_track.id is None:
-                self._next_track = UserPlaylistPlayer.next(self)
+            if next_track.id is None:
+                next_track = UserPlaylistPlayer.next(self, force)
 
             # Get a random album/track then
-            if self._next_track.id is None:
-                self._next_track = ShufflePlayer.next(self)
+            if next_track.id is None:
+                next_track = ShufflePlayer.next(self)
 
             # Get a linear track then
-            if self._next_track.id is None:
-                self._next_track = LinearPlayer.next(self)
+            if next_track.id is None:
+                next_track = LinearPlayer.next(self)
+            if next_track.is_youtube:
+                self._load_youtube(next_track, False)
+            self._next_track = next_track
             self.emit('next-changed')
         except Exception as e:
             print("Player::set_next", e)
@@ -534,6 +546,8 @@ class Player(BinPlayer, QueuePlayer, UserPlaylistPlayer, RadioPlayer,
             Lp().window.pulse(False)
         if self._current_track.id >= 0:
             ShufflePlayer._on_stream_start(self, bus, message)
-        self.set_next()
+        if not self.__do_not_update_next:
+            self.set_next()
+        self.__do_not_update_next = False
         self.set_prev()
         BinPlayer._on_stream_start(self, bus, message)
