@@ -356,6 +356,8 @@ class PopToolbarMenu(Gio.Menu):
                             GLib.Variant("s", str(Lp().player.context.next)))
             playback_action.connect('change-state', self.__on_change_state)
             Lp().add_action(playback_action)
+            if Lp().player.get_user_playlist_ids():
+                playback_menu.remove(2)
             self.insert_section(0, _("Playback"),
                                 playback_menu)
         self.insert_section(1, _("Playlists"),
@@ -428,6 +430,7 @@ class EditMenu(BaseMenu):
             @param GVariant
         """
         album = Album(self._object_id)
+        art_file = Lp().art.get_album_cache_name(album)
         artist_ids = []
         for track_id in album.track_ids:
             artist_ids += Lp().tracks.get_artist_ids(track_id)
@@ -449,6 +452,7 @@ class EditMenu(BaseMenu):
         with SqlCursor(Lp().db) as sql:
             sql.commit()
         GLib.idle_add(Lp().scanner.emit, 'album-updated', self._object_id)
+        Lp().art.clean_store(art_file)
 
     def __edit_tag(self, action, variant):
         """
@@ -603,6 +607,7 @@ class TrackMenuPopover(Gtk.Popover):
             hgrid.add(year)
         hgrid.show()
         if track.album.is_youtube:
+            grid.set_row_spacing(2)
             grid.add(edit)
         grid.add(hgrid)
         self.add(stack)
