@@ -21,7 +21,7 @@ from lollypop.define import Lp, ArtSize, Type, DbPersistent
 from lollypop.objects import Track, Album
 from lollypop.pop_menu import TrackMenuPopover, TrackMenu
 from lollypop.pop_album import AlbumPopover
-from lollypop.search_item import SearchItem
+from lollypop.utils import noaccents
 
 
 class SearchRow(Gtk.ListBoxRow):
@@ -38,6 +38,7 @@ class SearchRow(Gtk.ListBoxRow):
         Gtk.ListBoxRow.__init__(self)
         self.__item = item
         self.__uri_set = False
+        self.__score = None
         builder = Gtk.Builder()
         if internal:
             builder.add_from_resource(
@@ -60,11 +61,27 @@ class SearchRow(Gtk.ListBoxRow):
     @property
     def id(self):
         """
-            Return row id
+            Get row id
             @return int
         """
         return self.__item.id
 
+    @property
+    def score(self):
+        """
+            Get row score
+            @return int
+        """
+        return self.__score
+
+    @property
+    def name(self):
+        """
+            Get row name
+            @return str
+        """
+        return self.__name.get_text()
+
     @property
     def artist_ids(self):
         """
@@ -73,6 +90,14 @@ class SearchRow(Gtk.ListBoxRow):
         """
         return self.__item.artist_ids
 
+    @property
+    def artists(self):
+        """
+            Return row artist ids
+            @return artist ids as [int]
+        """
+        return self.__item.artists
+
     @property
     def is_track(self):
         """
@@ -110,6 +135,13 @@ class SearchRow(Gtk.ListBoxRow):
         else:
             yt.save_album(self.__item, DbPersistent.NONE)
 
+    def set_score(self, score):
+        """
+            Set score
+            @param score as int
+        """
+        self.__score = score
+
     def set_cover(self, pixbuf):
         """
             Set cover
@@ -143,7 +175,7 @@ class SearchRow(Gtk.ListBoxRow):
             Prepend track to queue
             @param button as Gtk.Button
         """
-        Lp().window.show_playlist_manager(self.__id, [], [],
+        Lp().window.show_playlist_manager(self.__item.id, [], [],
                                           not self.__is_track)
 
     def _on_queue_clicked(self, button):
@@ -152,9 +184,9 @@ class SearchRow(Gtk.ListBoxRow):
             @param button as Gtk.Button
         """
         if self.__item.is_track:
-            Lp().player.append_to_queue(self.__id)
+            Lp().player.append_to_queue(self.__item.id)
         else:
-            for track in Lp().albums.get_track_ids(self.__id, [], []):
+            for track in Lp().albums.get_track_ids(self.__item.id, [], []):
                 Lp().player.append_to_queue(track)
         button.set_sensitive(False)
         button.set_opacity(0.4)
@@ -229,11 +261,10 @@ class SearchPopover(Gtk.Popover):
         self.set_position(Gtk.PositionType.BOTTOM)
         self.connect('map', self.__on_map)
         self.connect('unmap', self.__on_unmap)
-        self.__in_thread = False
-        self.__stop_thread = False
         self.__timeout = None
         self.__current_search = ''
-        self.__search = None
+        self.__nsearch = None
+        self.__lsearch = None
 
         builder = Gtk.Builder()
         builder.add_from_resource('/org/gnome/Lollypop/SearchPopover.ui')
@@ -241,6 +272,7 @@ class SearchPopover(Gtk.Popover):
         self.__new_btn = builder.get_object('new_btn')
 
         self.__view = Gtk.ListBox()
+        self.__view.set_sort_func(self.__sort_func)
         self.__view.connect("button-press-event", self.__on_button_press)
         self.__view.connect("row-activated", self.__on_row_activated)
         self.__view.set_selection_mode(Gtk.SelectionMode.SINGLE)
@@ -279,13 +311,7 @@ class SearchPopover(Gtk.Popover):
             Timeout filtering
             @param widget as Gtk.TextEntry
         """
-        if self.__in_thread:
-            self.__stop_thread = True
-            self.__reset_search()
-            self.__stack.set_visible_child(self.__new_btn)
-            self.__spinner.stop()
-            GLib.timeout_add(100, self._on_search_changed, widget)
-
+        self.__reset_search()
         if self.__timeout:
             GLib.source_remove(self.__timeout)
             self.__timeout = None
@@ -293,12 +319,9 @@ class SearchPopover(Gtk.Popover):
         self.__current_search = widget.get_text().strip()
         if self.__current_search != "":
             self.__new_btn.set_sensitive(True)
-            self.__timeout = GLib.timeout_add(100,
+            self.__timeout = GLib.timeout_add(500,
                                               self.__on_search_changed_thread)
         else:
-            self.__reset_search()
-            self.__stack.set_visible_child(self.__new_btn)
-            self.__spinner.stop()
             self.__new_btn.set_sensitive(False)
             for child in self.__view.get_children():
                 GLib.idle_add(child.destroy)
@@ -322,115 +345,82 @@ class SearchPopover(Gtk.Popover):
 #######################
 # PRIVATE             #
 #######################
-    def __clear(self):
+    def __calculate_score(self, row):
+        """
+            Calculate score for row
+            @param row as SearchRow
+        """
+        if row.score is not None:
+            return
+        # Network search score less
+        if row.id is None:
+            score = 0
+            artists = row.artists
+        else:
+            score = 1
+            artists = []
+            for artist_id in row.artist_ids:
+                artists.append(Lp().artists.get_name(artist_id))
+
+        for item in self.__current_search.split():
+            for artist in artists:
+                if noaccents(artist.lower()).find(
+                                                noaccents(item).lower()) != -1:
+                    score += 2
+                    if not row.is_track:
+                        score += 1
+            if noaccents(row.name).lower().find(
+                                                noaccents(item).lower()) != -1:
+                score += 1
+                if row.is_track:
+                    score += 1
+        row.set_score(score)
+
+    def __sort_func(self, row1, row2):
+        """
+            Sort rows
+            @param row as SearchRow
+            @param row as SearchRow
+        """
+        self.__calculate_score(row1)
+        self.__calculate_score(row2)
+        return row1.score < row2.score
+
+    def __clear(self, rows):
         """
             Clear search view
+            @param items as [SearchRow]
             @warning not thread safe
         """
-        for child in self.__view.get_children():
-            child.destroy()
+        if rows:
+            row = rows.pop(0)
+            row.destroy()
+            GLib.idle_add(self.__clear, rows)
 
     def __populate(self):
         """
             Populate searching items
             in db based on text entry current text
         """
-        GLib.idle_add(self.__clear)
+        self.__stack.set_visible_child(self.__spinner)
+        self.__spinner.start()
 
         # Network Search
-        t = Thread(target=self.__network_search)
+        if self.__need_network_search():
+            t = Thread(target=self.__nsearch.do, args=(self.__current_search,))
+            t.daemon = True
+            t.start()
+
+        # Local Search
+        search_items = [self.__current_search]
+        for item in self.__current_search.split():
+            if len(item) >= 3:
+                search_items.append(item)
+        GLib.idle_add(self.__clear, self.__view.get_children())
+        t = Thread(target=self.__lsearch.do, args=(search_items,))
         t.daemon = True
         t.start()
 
-        # Local search
-        results = []
-        added_album_ids = []
-        added_track_ids = []
-        search_items = [self.__current_search]
-        # for item in self.__current_search.split():
-        #    if len(item) < 3:
-        #        search_items.append(item)
-        for item in search_items:
-            albums = []
-            tracks_non_album_artist = []
-            # Get all albums for all artists and non album_artist tracks
-            for artist_id in Lp().artists.search(item):
-                for album_id in Lp().albums.get_ids([artist_id], []):
-                    if (album_id, artist_id) not in albums:
-                        albums.append((album_id, artist_id))
-                for track_id, track_name in Lp(
-                                   ).tracks.get_as_non_album_artist(artist_id):
-                    tracks_non_album_artist.append((track_id, track_name))
-
-            for album_id, artist_id in albums:
-                if album_id in added_album_ids:
-                    continue
-                search_item = SearchItem()
-                search_item.id = album_id
-                added_album_ids.append(album_id)
-                search_item.is_track = False
-                search_item.artist_ids = [artist_id]
-                results.append(search_item)
-
-            albums = Lp().albums.search(item)
-            for album_id in albums:
-                if album_id in added_album_ids:
-                    continue
-                search_item = SearchItem()
-                search_item.id = album_id
-                added_album_ids.append(album_id)
-                search_item.is_track = False
-                search_item.artist_ids = Lp().albums.get_artist_ids(album_id)
-                results.append(search_item)
-
-            for track_id, track_name in Lp().tracks.search(
-                                               item) + tracks_non_album_artist:
-                if track_id in added_track_ids:
-                    continue
-                search_item = SearchItem()
-                search_item.id = track_id
-                added_track_ids.append(track_id)
-                search_item.is_track = True
-                search_item.artist_ids = Lp().tracks.get_artist_ids(track_id)
-                results.append(search_item)
-        if not self.__stop_thread:
-            GLib.idle_add(self.__add_rows_internal, results)
-        else:
-            self.__in_thread = False
-            self.__stop_thread = False
-            if not self.__need_network_search():
-                self.__stack.set_visible_child(self.__new_btn)
-                self.__spinner.stop()
-
-    def __network_search(self):
-        """
-            Search on network
-        """
-        if self.__need_network_search():
-            self.__search.do(self.__current_search)
-
-    def __add_rows_internal(self, results):
-        """
-            Add rows for internal results
-            @param results as array of SearchItem
-        """
-        if results:
-            result = results.pop(0)
-            search_row = SearchRow(result)
-            search_row.show()
-            self.__view.add(search_row)
-            if self.__stop_thread:
-                self.__in_thread = False
-                self.__stop_thread = False
-            else:
-                GLib.idle_add(self.__add_rows_internal, results)
-        else:
-            self.__in_thread = False
-            self.__stop_thread = False
-            if not self.__need_network_search():
-                self.__stack.set_visible_child(self.__new_btn)
-                self.__spinner.stop()
-
     def __download_cover(self, uri, row):
         """
             Download row covers
@@ -513,10 +503,16 @@ class SearchPopover(Gtk.Popover):
         """
             Reset search object
         """
-        if self.__search is not None:
-            self.__search.disconnect_by_func(self.__on_item_found)
-            self.__search.stop()
-            self.__search = None
+        self.__stack.set_visible_child(self.__new_btn)
+        self.__spinner.stop()
+        if self.__nsearch is not None:
+            self.__nsearch.disconnect_by_func(self.__on_network_item_found)
+            self.__nsearch.stop()
+            self.__nsearch = None
+        if self.__lsearch is not None:
+            self.__lsearch.disconnect_by_func(self.__on_local_item_found)
+            self.__lsearch.stop()
+            self.__lsearch = None
 
     def __need_network_search(self):
         """
@@ -526,17 +522,35 @@ class SearchPopover(Gtk.Popover):
         return Lp().settings.get_value('network-search') and\
             which("youtube-dl") is not None
 
-    def __on_item_found(self, search):
+    def __on_local_item_found(self, search):
+        """
+            Add rows for internal results
+            @param search as LocalSearch
+        """
+        if self.__lsearch != search:
+            return
+        if not search.items:
+            if self.__lsearch.finished and\
+                    (self.__nsearch is None or self.__nsearch.finished):
+                self.__stack.set_visible_child(self.__new_btn)
+                self.__spinner.stop()
+            return
+        item = search.items.pop(0)
+        search_row = SearchRow(item)
+        search_row.show()
+        self.__view.add(search_row)
+
+    def __on_network_item_found(self, search):
         """
             Add rows for internal results
             @param search as NetworkSearch
         """
-        if self.__search != search:
+        if self.__nsearch != search:
             return
-        if search.finished:
-            self.__stack.set_visible_child(self.__new_btn)
-            self.__spinner.stop()
         if not search.items:
+            if self.__nsearch.finished and self.__lsearch.finished:
+                self.__stack.set_visible_child(self.__new_btn)
+                self.__spinner.stop()
             return
         item = search.items.pop(0)
         if item.exists_in_db():
@@ -574,16 +588,16 @@ class SearchPopover(Gtk.Popover):
         """
             Populate widget
         """
+        self.__reset_search()
+        from lollypop.search_local import LocalSearch
         from lollypop.search_network import NetworkSearch
         self.__timeout = None
-        self.__in_thread = True
-        self.__search = NetworkSearch()
-        self.__search.connect('item-found', self.__on_item_found)
-        self.__stack.set_visible_child(self.__spinner)
-        self.__spinner.start()
-        t = Thread(target=self.__populate)
-        t.daemon = True
-        t.start()
+        self.__lsearch = LocalSearch()
+        self.__lsearch.connect('item-found', self.__on_local_item_found)
+        if self.__need_network_search():
+            self.__nsearch = NetworkSearch()
+            self.__nsearch.connect('item-found', self.__on_network_item_found)
+        self.__populate()
 
     def __on_row_activated(self, widget, row):
         """
