@@ -17,7 +17,6 @@ except:
     Secret = None
 
 
-from os import remove
 from gettext import gettext as _
 from gettext import ngettext as ngettext
 from threading import Thread
@@ -133,9 +132,17 @@ class SettingsDialog:
 
         switch_artwork_tags = builder.get_object('switch_artwork_tags')
         if which("kid3-cli") is None:
-            switch_artwork_tags.set_sensitive(False)
-            switch_artwork_tags.set_tooltip_text(
-                                            _("You need to install kid3-cli"))
+            grid = builder.get_object('grid_behaviour')
+            h = grid.child_get_property(switch_artwork_tags, 'height')
+            w = grid.child_get_property(switch_artwork_tags, 'width')
+            l = grid.child_get_property(switch_artwork_tags, 'left-attach')
+            t = grid.child_get_property(switch_artwork_tags, 'top-attach')
+            switch_artwork_tags.destroy()
+            label = Gtk.Label.new(_("You need to install kid3-cli"))
+            label.get_style_context().add_class('dim-label')
+            label.set_property('halign', Gtk.Align.END)
+            label.show()
+            grid.attach(label, l, t, w, h)
         else:
             switch_artwork_tags.set_state(
                                       Lp().settings.get_value('artwork-tags'))
@@ -645,13 +652,10 @@ class SettingsDialog:
             GLib.idle_add(self.___reset_database, track_ids,
                           count, history, progress)
         else:
+            Lp().db.del_tracks(Lp().tracks.get_ids())
             progress.hide()
-            for artist in Lp().artists.get([]):
-                Lp().art.emit('artist-artwork-changed', artist[1])
-            remove(Database.DB_PATH)
             Lp().db = Database()
             Lp().window.show_genres(Lp().settings.get_value('show-genres'))
-            Lp().window.show()
             Lp().window.update_db()
             progress.get_toplevel().set_deletable(True)
 
