@@ -15,8 +15,9 @@ from gi.repository import Gtk, GLib, Gdk
 from lollypop.view import View, LazyLoadingView
 from lollypop.widgets_album import AlbumSimpleWidget
 from lollypop.pop_album import AlbumPopover
-from lollypop.pop_menu import AlbumMenu
+from lollypop.pop_menu import AlbumMenu, AlbumMenuPopover
 from lollypop.objects import Album
+from lollypop.define import Type
 
 
 class AlbumsView(LazyLoadingView):
@@ -127,8 +128,15 @@ class AlbumsView(LazyLoadingView):
             self._scrolled.get_allocation().height + y
             self._scrolled.get_vadjustment().set_value(y)
         if self.__press_rect is not None:
-            pop_menu = AlbumMenu(Album(album_widget.get_id()))
-            popover = Gtk.Popover.new_from_model(cover, pop_menu)
+            album = Album(album_widget.id)
+            if self.__genre_ids and self.__genre_ids[0] == Type.CHARTS:
+                popover = AlbumMenuPopover(album, None)
+                popover.set_relative_to(cover)
+            elif album.is_youtube:
+                popover = AlbumMenuPopover(album, AlbumMenu(album))
+                popover.set_relative_to(cover)
+            else:
+                popover = Gtk.Popover.new_from_model(cover, AlbumMenu(album))
             popover.set_position(Gtk.PositionType.BOTTOM)
             popover.set_pointing_to(self.__press_rect)
         else:
@@ -141,7 +149,7 @@ class AlbumsView(LazyLoadingView):
                 height = bottom_height
             else:
                 height = top_height
-            popover = AlbumPopover(album_widget.get_id(),
+            popover = AlbumPopover(album_widget.id,
                                    self.__genre_ids,
                                    self.__artist_ids,
                                    allocation.width,
