@@ -77,7 +77,7 @@ class ArtistAlbumsView(LazyLoadingView):
         """
         widget = None
         for child in self._albumbox.get_children():
-            if child.get_id() == Lp().player.current_track.album.id:
+            if child.id == Lp().player.current_track.album.id:
                 widget = child
                 break
         if widget is not None:
